# mypy-boto3-glacier

[![PyPI - mypy-boto3-glacier](https://img.shields.io/pypi/v/mypy-boto3-glacier.svg?color=blue)](https://pypi.org/project/mypy-boto3-glacier)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-glacier.svg?color=blue)](https://pypi.org/project/mypy-boto3-glacier)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Glacier 1.17.26](https://boto3.amazonaws.com/v1/documentation/api/1.17.26/reference/services/glacier.html#Glacier) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 4.4.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-glacier](#mypy-boto3-glacier)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Glacier` service.

```bash
python -m pip install boto3-stubs[glacier]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[glacier]` in your environment: `python -m pip install 'boto3-stubs[glacier]'`

Both type checking and auto-complete should work for `Glacier` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[glacier]` in your environment: `python -m pip install 'boto3-stubs[glacier]'`

Both type checking and auto-complete should work for `Glacier` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[glacier]` in your environment: `python -m pip install 'boto3-stubs[glacier]'`
- Run `mypy` as usual

Type checking should work for `Glacier` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[glacier]` in your environment: `python -m pip install 'boto3-stubs[glacier]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Glacier` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`GlacierClient` provides annotations for `boto3.client("glacier")`.

```python
import boto3

from mypy_boto3_glacier import GlacierClient

client: GlacierClient = boto3.client("glacier")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: GlacierClient = session.client("glacier")
```

### Paginators annotations

`mypy_boto3_glacier.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_glacier import GlacierClient
from mypy_boto3_glacier.paginator import (
    ListJobsPaginator,
    ListMultipartUploadsPaginator,
    ListPartsPaginator,
    ListVaultsPaginator,
)

client: GlacierClient = boto3.client("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
list_multipart_uploads_paginator: ListMultipartUploadsPaginator = client.get_paginator("list_multipart_uploads")
list_parts_paginator: ListPartsPaginator = client.get_paginator("list_parts")
list_vaults_paginator: ListVaultsPaginator = client.get_paginator("list_vaults")
```


### Waiters annotations

`mypy_boto3_glacier.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_glacier import GlacierClient
from mypy_boto3_glacier.waiter import (
    VaultExistsWaiter,
    VaultNotExistsWaiter,
)

client: GlacierClient = boto3.client("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
vault_exists_waiter: VaultExistsWaiter = client.get_waiter("vault_exists")
vault_not_exists_waiter: VaultNotExistsWaiter = client.get_waiter("vault_not_exists")
```


### Service Resource annotations

`GlacierServiceResource` provides annotations for `boto3.resource("glacier")`.

```python
from mypy_boto3_glacier import GlacierServiceResource

resource: GlacierServiceResource = boto3.resource("glacier")

# now resource usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_resource: GlacierServiceResource = session.resource("glacier")
```


### Other resources annotations

`mypy_boto3_glacier.service_resource` module contains type annotations for all resources.

```python
from mypy_boto3_glacier import GlacierServiceResource
from mypy_boto3_glacier.service_resource import (
    Account,
    Archive,
    Job,
    MultipartUpload,
    Notification,
    Vault,
)

resource: GlacierServiceResource = boto3.resource("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
my_account: Account = resource.Account(...)
my_archive: Archive = resource.Archive(...)
my_job: Job = resource.Job(...)
my_multipart_upload: MultipartUpload = resource.MultipartUpload(...)
my_notification: Notification = resource.Notification(...)
my_vault: Vault = resource.Vault(...)
```



### Collections annotations

`mypy_boto3_glacier.service_resource` module contains type annotations
for all `GlacierServiceResource` collections.

```python
from mypy_boto3_glacier import GlacierServiceResource
from mypy_boto3_glacier.service_resource import (
    ServiceResourceVaultsCollection,
)

resource: GlacierServiceResource = boto3.resource("glacier")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
vaults: glacier_resources.ServiceResourceVaultsCollection = resource.vaults
```




### Typed dictionations

`mypy_boto3_glacier.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_glacier.type_defs import (
    CSVInputTypeDef,
    CSVOutputTypeDef,
    DataRetrievalPolicyTypeDef,
    DataRetrievalRuleTypeDef,
    DescribeVaultOutputTypeDef,
    EncryptionTypeDef,
    GlacierJobDescriptionTypeDef,
    GrantTypeDef,
    GranteeTypeDef,
    InputSerializationTypeDef,
    InventoryRetrievalJobDescriptionTypeDef,
    InventoryRetrievalJobInputTypeDef,
    OutputLocationTypeDef,
    OutputSerializationTypeDef,
    PartListElementTypeDef,
    ProvisionedCapacityDescriptionTypeDef,
    ResponseMetadata,
    S3LocationTypeDef,
    SelectParametersTypeDef,
    UploadListElementTypeDef,
    VaultAccessPolicyTypeDef,
    VaultNotificationConfigTypeDef,
    ArchiveCreationOutputTypeDef,
    CreateVaultOutputTypeDef,
    GetDataRetrievalPolicyOutputTypeDef,
    GetJobOutputOutputTypeDef,
    GetVaultAccessPolicyOutputTypeDef,
    GetVaultLockOutputTypeDef,
    GetVaultNotificationsOutputTypeDef,
    InitiateJobOutputTypeDef,
    InitiateMultipartUploadOutputTypeDef,
    InitiateVaultLockOutputTypeDef,
    JobParametersTypeDef,
    ListJobsOutputTypeDef,
    ListMultipartUploadsOutputTypeDef,
    ListPartsOutputTypeDef,
    ListProvisionedCapacityOutputTypeDef,
    ListTagsForVaultOutputTypeDef,
    ListVaultsOutputTypeDef,
    PaginatorConfigTypeDef,
    PurchaseProvisionedCapacityOutputTypeDef,
    UploadMultipartPartOutputTypeDef,
    VaultLockPolicyTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> CSVInputTypeDef:
    return {
      ...
    }
```
